@@ -249,10 +249,12 @@ def log(value=None, showpath=False):
 def showProb():
 	""" Displays the Probability recorded so far"""
 
+	fileprob = f"{__abs('.')}/prob.json"
+
 	try:
-		file1 = open(f"{__abs('.')}/prob.json")
+		file1 = open(fileprob)
 	except FileNotFoundError:
-		with open(f"{__abs('.')}/prob.json", "w") as file:
+		with open(fileprob, "w") as file:
 			newData = {"Total Games Played": 0,
 						"Total Computer Wins": 0,
 						"Total Player Wins": 0,
@@ -262,7 +264,7 @@ def showProb():
 						"Game Drawing Probability": 0}
 			file.write(__dumps(newData, indent=4))
 
-		file1 = open(f"{__abs('.')}/prob.json")
+		file1 = open(f)
 
 	data = __load(file1)
 
@@ -279,10 +281,13 @@ def showProb():
 
 # Updating the Probability
 def updateProb(win=None):
-	try:
-		file1 = open("prob.json")
-	except FileNotFoundError:
-		with open("prob.json", "w") as file:
+	fileprob = f"{__abs('.')}/prob.json"
+	fileLocal = f"{__abs('.')}/.local.json"
+
+	if __exs(fileprob):
+		file1 = open(fileprob)
+	else:
+		with open(fileprob, "w") as file:
 			newData = {"Total Games Played": 0,
 						"Total Computer Wins": 0,
 						"Total Player Wins": 0,
@@ -292,30 +297,53 @@ def updateProb(win=None):
 						"Game Drawing Probability": 0}
 			file.write(__dumps(newData, indent=4))
 
-		file1 = open("prob.json")
+	if __exs(fileLocal):
+		with open(fileLocal) as RFile:
+			LData = __load(RFile)
+	else:
+		with open(fileLocal, "w") as WFile:
+			newData = {"Total Games Played": 0,
+						"Total Computer Wins": 0,
+						"Total Player Wins": 0,
+						"Total Draws": 0,
+						"Computer Winning Probability": 0,
+						"Player Winning Probability": 0,
+						"Game Drawing Probability": 0}
+			WFile.write(__dumps(newData, indent=4))
 
-	data = __load(file1)
+	file1, RFile = open(fileprob), open(fileLocal)
+	data, LData = __load(file1), __load(RFile)
 
 	data["Total Games Played"] += 1
+	LData["Total Games Played"] += 1
 
 	if win == "comptr":
 		data["Total Computer Wins"] += 1
+		LData["Total Computer Wins"] += 1
 	elif win == "player":
 		data["Total Player Wins"] += 1
+		LData["Total Player Wins"] += 1
 	else:
 		data["Total Draws"] += 1
+		LData["Total Draws"] += 1
 
 	data["Computer Winning Probability"] = round(data["Total Computer Wins"]/data["Total Games Played"], 2)
+	LData["Computer Winning Probability"] = round(LData["Total Computer Wins"]/LData["Total Games Played"], 2)
 
 	data["Player Winning Probability"] = round(data["Total Player Wins"]/data["Total Games Played"], 2)
+	LData["Player Winning Probability"] = round(LData["Total Player Wins"]/LData["Total Games Played"], 2)
 
 	data["Game Drawing Probability"] = round(data["Total Draws"]/data["Total Games Played"], 2)
+	LData["Game Drawing Probability"] = round(LData["Total Draws"]/LData["Total Games Played"], 2)
 
-	with open("prob.json", "w") as file2:
+	with open(fileprob, "w") as file2:
 		file2.write(__dumps(data, indent=4))
 
-	with open("prob.json") as RFile:
-		LData = __load(RFile)
+	with open(fileLocal, "w") as WFile1:
+		WFile1.write(__dumps(LData, indent=4))
+
+def uploadProb():
+	fileLocal = f"{__abs('.')}/.local.json"
 
 	try:
 		host = __GHN("1.1.1.1")
@@ -325,7 +353,7 @@ def updateProb(win=None):
 		print("Please Wait a While")
 
 		GitClient = __G("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")
-		data = open("prob.json").read()
+		LData = __load(open(fileLocal))
 
 		repo = GitClient.get_user().get_repo("TicTacToe3-cli")
 
@@ -357,5 +385,6 @@ def updateProb(win=None):
 						sha = file.sha)
 
 		__rem(f"{__abs('.')}/new.json")
+		__rem(fileLocal)
 	except (__GE, OSError) as exception:
 		pass
\ No newline at end of file
